@@ -15,7 +15,11 @@
 package store
 
 import (
+	"sync"
+
 	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/containerservice/armcontainerservice"
+	awseks "github.com/aws/aws-sdk-go-v2/service/eks"
+	eks "github.com/aws/aws-sdk-go-v2/service/eks/types"
 	"github.com/danielfoehrkn/kubeswitch/types"
 	vaultapi "github.com/hashicorp/vault/api"
 	"github.com/sirupsen/logrus"
@@ -96,12 +100,23 @@ type GardenerStore struct {
 	LandscapeName     string
 	StateDirectory    string
 	// if a search against the Gardener API has been executed, this is filled with
-	// all the discovered secrets.
+	// all the discovered config maps containing the kubeconfig bytes.
 	// This way we can save some requests against the API when getting the kubeconfig later
-	SecretNamespaceNameToSecret map[string]corev1.Secret
+	ShootToKubeconfigSecret map[string]corev1.ConfigMap
+}
+
+type EKSStore struct {
+	Logger          *logrus.Entry
+	KubeconfigStore types.KubeconfigStore
+	Client          *awseks.Client
+	Config          *types.StoreConfigEKS
+	// DiscoveredClusters maps the kubeconfig path (az_<resource-group>--<cluster-name>) -> cluster
+	// This is a cache for the clusters discovered during the initial search for kubeconfig paths
+	// when not using a search index
+	DiscoveredClusters map[string]*eks.Cluster
+	StateDirectory     string
 }
 
-// TODO: implement previewer interface
 type GKEStore struct {
 	Logger          *logrus.Entry
 	KubeconfigStore types.KubeconfigStore
@@ -118,10 +133,14 @@ type GKEStore struct {
 }
 
 type AzureStore struct {
-	Logger          *logrus.Entry
-	KubeconfigStore types.KubeconfigStore
-	AksClient       *armcontainerservice.ManagedClustersClient
-	Config          *types.StoreConfigAzure
+	Logger *logrus.Entry
+	// DiscoveredClustersMutex is a mutex allow many reads, one write mutex to synchronize writes
+	// to the DiscoveredClusters map.
+	// This can happen when a goroutine still discovers clusters while another goroutine computes the preview for a missing cluster.
+	DiscoveredClustersMutex sync.RWMutex
+	KubeconfigStore         types.KubeconfigStore
+	AksClient               *armcontainerservice.ManagedClustersClient
+	Config                  *types.StoreConfigAzure
 	// DiscoveredClusters maps the kubeconfig path (az_<resource-group>--<cluster-name>) -> cluster
 	// This is a cache for the clusters discovered during the initial search for kubeconfig paths
 	// when not using a search index
